/////////////////////////////////// GPS Functions ////////////////////////////////
#if (GPS_USED) // Don't do anything in this tab unless the GPS is being used!

bool readGPS(){  //  request and get a sentence from the GPS
  strcpy_P(dispBuff, (char*)pgm_read_word(&(cmnd_table[RMC_READ]))); 
  Serial.print(dispBuff);               // Request RMC message from GPS
  while (Serial.available()){           // Get sentence from GPS
    if (gps.encode(Serial.read())) return true;
  }
  return false;
}


time_t gpsTimeSync(){  //  returns time if avail from gps, else returns 0
  unsigned long fix_age = 0 ;
  strcpy_P(dispBuff, (char*)pgm_read_word(&(cmnd_table[RMC_READ]))); 
  Serial.print(dispBuff);             // Request RMC message from GPS
  while (Serial.available()){
    gps.encode(Serial.read());
  }
  gps.get_datetime(NULL,NULL, &fix_age);

  if(fix_age < 1000) return gpsTimeToArduinoTime();   // only return time if recent fix  
  return 0;
}


time_t gpsTimeToArduinoTime(){  // returns time_t from GPS with GMT_Offset for hours
  tmElements_t tm;
  int year;
  readGPS();                            // request RMC from GPS and feed to tinyGPS
  gps.crack_datetime(&year, &tm.Month, &tm.Day, &tm.Hour, &tm.Minute, &tm.Second, NULL, NULL);
  tm.Year = year - 1970; 
  time_t time = makeTime(tm);
#if (AUTO_DST == 1)
  if (InDST()) time = time + SECS_PER_HOUR;
#endif
  return time + (GMT_Offset * SECS_PER_HOUR);
}


void GPSinit(){   // send commands to the GPS for what to output - uses PROGMEM for this
  strcpy_P(dispBuff, (char*)pgm_read_word(&(cmnd_table[DDM_OFF]))); 
  Serial.print(dispBuff);
  delay(250);
  strcpy_P(dispBuff, (char*)pgm_read_word(&(cmnd_table[GGA_OFF]))); 
  Serial.print(dispBuff);
  delay(250);
  strcpy_P(dispBuff, (char*)pgm_read_word(&(cmnd_table[GLL_OFF]))); 
  Serial.print(dispBuff);
  delay(250);
  strcpy_P(dispBuff, (char*)pgm_read_word(&(cmnd_table[GSA_OFF]))); 
  Serial.print(dispBuff);
  delay(250);
  strcpy_P(dispBuff, (char*)pgm_read_word(&(cmnd_table[GSV_OFF]))); 
  Serial.print(dispBuff);
  delay(250);
  strcpy_P(dispBuff, (char*)pgm_read_word(&(cmnd_table[RMC_OFF]))); 
  Serial.print(dispBuff);
  delay(250);
  strcpy_P(dispBuff, (char*)pgm_read_word(&(cmnd_table[VTG_OFF]))); 
  Serial.print(dispBuff);
  delay(250);
  strcpy_P(dispBuff, (char*)pgm_read_word(&(cmnd_table[WAAS_OFF]))); 
  Serial.print(dispBuff);  //NOTE CHECKSUM MAY BE WRONG!
}
#endif

