////////////////////////////// Logging Functions Here ///////////////////////////////

void LogCount(unsigned long lcnt){
  // SD File format: "Date", "Time", latitude, longitude, speed, CPM, uSv/hr, Vcc
  bool newdata = false; //TODO
  float flat, flon;
  unsigned long age;
  FormatDateTime();                     // format the latest time into the strings
  Vcc_mV = readVcc();                   // check voltage
  if (Vcc_mV <= LOW_VCC) lowVcc = true; // check if Vcc is low 
  else lowVcc = false;

  // Date & Time . . .
  logfile.print("\"");                  // log the time and date (quoted)
  logfile.print(dateString);            // formatted date string
  logfile.print("\",\"");               // and comma delimited
  logfile.print(timeString);            // formatted time string
#if (AM_PM_FMT)                         // print AM/PM if defined
  if (isPM()) logfile.print("pm"); 
  else logfile.print("am");
#endif
  logfile.print("\",");                 // comma delimited

  // GPS . . .
#if (GPS_USED == 1)
  readGPS();                              // get a reading
  newdata = true; // FORCING THIS FOR NOW
  gps.f_get_position(&flat, &flon, &age); // get the current GPS position
  logfile.print(flat,8);                  // now log the lat from the GPS
  logfile.print(",");                     // comma delimited
  logfile.print(flon,8);                  // now log the lon from the GPS
  logfile.print(",");                     // comma delimited
  if (SPEED_KMPH) logfile.print(gps.f_speed_kmph(),1); // now log the speed from the GPS
  else logfile.print(gps.f_speed_mph(),1);
  logfile.print(",");                     // comma delimited
#endif

  // Log counts . . .
  logCPM = float(lcnt) / (float(LoggingPeriod) / 60000);

  uSvLogged = logCPM / uSvRate;         // make uSV conversion
  logfile.print(logCPM,DEC); // log the CPM
  logfile.print(",");                   // comma delimited
  logfile.print(uSvLogged,4);
  logfile.print(",");                   // comma delimited
  logfile.print(Vcc_mV/1000. ,2);       //convert to Float, divide, and print 2 dec places
  logfile.print(","); // comma delimited
  logfile.println();

  // really need to tell if the GPS has a fix
  if (newdata = true) Blink(LED_PIN,1); // show it's receiving
  logfile.flush();                      // close the file
}


void initCard(){   // initialize the SD card
  pinMode(10, OUTPUT);                  // must set DEFAULT CS pin output, even if not used
  if (LoggingPeriod == 0){              // logging turned off
    error("No Log");
    return;
  }

  if (!SD.begin(CS_PIN)) { // see if the card is present and can be initialized:
    error("Card");
  }
  char filename[] = "GPSLOG00.CSV";     // create a new file
  for (uint8_t i = 0; i < 100; i++) {
    filename[6] = i/10 + '0';
    filename[7] = i%10 + '0';
    if (! SD.exists(filename)) {
      logfile = SD.open(filename, FILE_WRITE);  // only open a new file if it doesn't exist
      break;  // leave the loop!
    }
  }
  if (! logfile) {
    error("File");
    return;
  }
  clearDisp();                          // clear the screen
  lcd.print("Log File:");               // display filename you're are logging to . . .
  lcd.setCursor(0,1);
  lcd.print(filename);                  // this file name 
  delay (3000);                         // leave the banner up 3 sec.

  // Begin header for Excel file - using PROGMEM for some of the header lits
  strcpy_P(dispBuff, (char*)pgm_read_word(&(lit_table[4]))); //("Date,Time,")
  logfile.print(dispBuff);
#if (GPS_USED == 1)
  strcpy_P(dispBuff, (char*)pgm_read_word(&(lit_table[5]))); //("latitude,longitude,")
  logfile.print(dispBuff);
  if (SPEED_KMPH) logfile.print("KMPH,");
  else logfile.print("MPH,");
#endif
  strcpy_P(dispBuff, (char*)pgm_read_word(&(lit_table[6]))); //("CPM,uSv,Vcc")
  logfile.println(dispBuff);
}


void error(char *str){
  clearDisp();                          // clear the screen
  lcd.print("CARD!");
  lcd.setCursor(0,1);
  lcd.print(str);                       // display this error or status
  digitalWrite(LED_PIN, HIGH);          // red LED indicates error
  SD_OK = false;                        // don't try to write to the SD card
  delay (2000);
}

