///////////////////////////////// Time Functions Here ///////////////////////////////

void FormatDateTime(){  // get the time and date from the GPS and format it
  int dispYear;
  memset(timeString,0,sizeof(timeString));  // initialize the strings
  memset(dateString,0,sizeof(dateString));

  // convert Sun=1 format to Sun=7 format (DST calc is based on this)
  day_of_week = (weekday()==1) ? 7: (weekday() - 1);

  dispYear = year() -2000;                 // (creates a bug in 89 years)
  if (dispYear <0) dispYear =0;            // no negative year if no fix

  // (The time lib will deal with AM/PM and 12 hour clock)
  // make time string
#if (AM_PM_FMT)
  AppendToString (hourFormat12(),timeString); // add 12 hour time to string
#else
  AppendToString (hour(),timeString);         // add 24 hour time to string
#endif
  strcat(timeString,":");
  if (minute() < 10) strcat(timeString,"0");
  AppendToString (minute(),timeString);       // add MINUTES to string
  if (NO_SECONDS == false){
    strcat(timeString,":");
    if (second() < 10) strcat(timeString,"0");
    AppendToString (second(),timeString);     // add SECONDS to string
  }
  // make date string
  if (DATE_FMT == DDMMYY)AppendToString (day(),dateString);          // add DAY to string
  else if(DATE_FMT == MMDDYY)  AppendToString (month(),dateString);  // add MONTH to string  
  else {                                                             // add YEAR to string
    if (dispYear < 10) strcat(dateString,"0");
    AppendToString (dispYear,dateString);
  }  
  strcat(dateString,"/");
  if (DATE_FMT == MMDDYY)AppendToString (day(),dateString);          // add DAY to string
  else AppendToString (month(),dateString);                          // add MONTH to string  
  strcat(dateString,"/");
  if (DATE_FMT == YYMMDD)AppendToString (day(),dateString);          // add DAY to string
  else {
    if (dispYear < 10) strcat(dateString,"0");
    AppendToString (dispYear,dateString);                            // add YEAR to string
  }
}


void AppendToString (int iValue, char *pString){ // appends a byte to string passed
  char tempStr[6];
  memset(tempStr,'\0',sizeof(tempStr));
  itoa(iValue,tempStr,10);
  strcat(pString,tempStr);
}


void dispDateTime(){   // display date and time on LCD
  clearArea (0,1,16);                   // clear the second line
  FormatDateTime();                     // format the latest time into the strings
  lcd.print(dateString);                // formatted date string
  lcd.print(" ");
  lcd.print(timeString);                // formatted time string
#if (AM_PM_FMT)                         // print AM/PM if defined
  if (isPM()) lcd.print("pm"); 
  else lcd.print("am");
#endif
}


void printDigits(int digits){   // prints preceding colon and leading 0
  lcd.print(":");
  if(digits < 10) lcd.print('0');
  lcd.print(digits);
}


bool InDST(){  // Returns true if in DST - Caution: works for US standard only
  // DST starts the 2nd Sunday in March and ends the 1st Sunday in November
  byte DOWinDST, nextSun;
  int Dy, Mn;  

  Dy = tmDay;
  Mn = tmMonth;
  //Dy = 27;  // FOR TESTING
  //Mn = 7;

  // Pre-qualify for in DST in the widest range (any date between 3/8 and 11/7) 
  if ((Mn == 3 && Dy >= 8) || (Mn > 3 && Mn < 11) || (Mn == 11 && Dy <= 7) ){
    // DST start could be as late as 3/14 and end as early as 11/1
    DOWinDST = true;                    // assume it's in DST until proven otherwise
    nextSun = Dy + (7 - day_of_week);   // find the date of the next Sunday
    if (nextSun == Dy) nextSun += 7;    // take care of today being Sunday
    if (Mn == 3 && (Dy <= nextSun)) DOWinDST = false;     // it's before the 2nd Sun in March
    if (Mn == 11 && (Dy >= nextSun -7)) DOWinDST = false; // it's after the 1st Sun in Nov.
    if (DOWinDST)return true;           // DOW is still OK so it's in DST
  }
  return false;                         // Nope, not in DST
}

